# Contributing

We love pull requests. Here's a quick guide.

Fork, then clone the repo:

    git clone git@github.com:your-username/far.git

Set up your machine:
* Install dependencies:
    `pip install -r requirements-dev.txt`
* Run tests:
    * `nosetests`: Run with default python distribution
    * `make`: Run test for python2.7 and python3
* Install from source code:
    `make install` or `sudo make install` depending on your permissions.


Make your change. Add tests for your change. Make the tests pass:

Push to your fork and [submit a pull request][pr].

[pr]: https://github.com/shubhamchaudhary/far/compare/

At this point you're waiting on us. We will not disappoint you.

Some things that we'd love to see in your pull request are:

* Follow coding style of the current source code.
* Write a good commit message.

